@@ -52,8 +52,9 @@ use Coro::Channel;
 use Coro::ProcessPool::Process;
 use Coro::ProcessPool::Util;
 use Coro::Semaphore;
+require Coro::ProcessPool::Pipeline;
 
-our $VERSION = '0.22';
+our $VERSION = '0.23';
 
 if ($^O eq 'MSWin32') {
     die 'MSWin32 is not supported';
@@ -85,7 +86,7 @@ memory over time.
 has max_reqs => (
     is      => 'ro',
     isa     => Int,
-    default => 0,
+    default => sub { 0 },
 );
 
 =head1 PRIVATE ATTRIBUTES
@@ -116,7 +117,7 @@ Running total of processes that are currently running.
 has num_procs => (
     is      => 'rw',
     isa     => Int,
-    default => 0,
+    default => sub { 0 },
 );
 
 =head2 procs
@@ -141,7 +142,7 @@ called.
 has is_running => (
     is      => 'rw',
     isa     => Bool,
-    default => 1,
+    default => sub { 1 },
 );
 
 =head1 METHODS
@@ -299,6 +300,38 @@ sub defer {
     return sub { $cv->recv };
 }
 
+=head2 pipeline
+
+Returns a L<Coro::ProcessPool::Pipeline> object which can be used to pipe
+requests through to the process pool. Results then come out the other end of
+the pipe.  It is up to the calling code to perform task account (for example,
+by passing an id in as one of the arguments to the task class).
+
+    my $pipe = $pool->pipeline;
+
+    my $producer = async {
+        foreach my $args (@tasks) {
+            $pipe->queue('Some::Class', $args);
+        }
+
+        $pipe->shutdown;
+    };
+
+    while (my $result = $pipe->next) {
+        ...
+    }
+
+All arguments to C<pipeline()> are passed transparently to the constructor of
+L<Coro::ProcessPool::Pipeline>. There is no limit to the number of pipelines
+which may be created for a pool.
+
+=cut
+
+sub pipeline {
+    my $self = shift;
+    return Coro::ProcessPool::Pipeline->new(@_);
+}
+
 =head1 A NOTE ABOUT IMPORTS AND CLOSURES
 
 Code refs are serialized using L<Storable> to pass them to the worker
